"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require("lodash");

var _utils = require("../../utils");

var ruleName = "custom-media-pattern";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: "Expected custom media query name to match specified pattern"
});

exports.messages = messages;

exports["default"] = function (pattern) {
  return function (root, result) {
    (0, _utils.validateOptions)({ result: result, ruleName: ruleName, actual: pattern, possible: _lodash.isRegExp });

    root.eachAtRule(function (atRule) {
      if (atRule.name !== "custom-media") {
        return;
      }

      var customMediaName = atRule.params.match(/^--(\S+)\b/)[1];

      if (!pattern.test(customMediaName)) {
        (0, _utils.report)({
          message: messages.expected,
          node: atRule,
          result: result,
          ruleName: ruleName
        });
      }
    });
  };
};