"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mediaFeatureColonSpaceChecker = mediaFeatureColonSpaceChecker;

var _utils = require("../../utils");

var ruleName = "media-feature-colon-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \":\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after \":\"";
  }
});

exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return function (root, result) {
    (0, _utils.validateOptions)({ result: result, ruleName: ruleName,
      actual: expectation,
      possible: ["always", "never"]
    });

    mediaFeatureColonSpaceChecker(checker.after, root, result);
  };
};

function mediaFeatureColonSpaceChecker(checkLocation, root, result) {
  root.eachAtRule(function (atRule) {
    var params = atRule.params;
    (0, _utils.styleSearch)({ source: params, target: ":" }, function (match) {
      checkColon(params, match.startIndex, atRule);
    });
  });

  function checkColon(source, index, node) {
    checkLocation({ source: source, index: index, err: function err(m) {
        return (0, _utils.report)({
          message: m,
          node: node,
          result: result,
          ruleName: ruleName
        });
      }
    });
  }
}