"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _lodash = require("lodash");

var _execall = require("execall");

var _execall2 = _interopRequireDefault(_execall);

var _utils = require("../../utils");

var ruleName = "number-max-precision";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: function expected(number, precision) {
    return "Expected \"" + number + "\" to be \"" + number.toFixed(precision) + "\"";
  }
});

exports.messages = messages;

exports["default"] = function (precision) {
  return function (root, result) {
    (0, _utils.validateOptions)({ result: result, ruleName: ruleName,
      actual: precision,
      possible: [_lodash.isNumber]
    });

    root.eachDecl(function (decl) {
      // Don't bother with strings
      if (decl.prop === "content") {
        return;
      }
      check(decl.value, decl);
    });

    root.eachAtRule(function (atRule) {
      check(atRule.params, atRule);
    });

    function check(source, node) {
      var decimalNumberMatches = (0, _execall2["default"])(/(\d*\.(\d+))/g, source);
      if (!decimalNumberMatches) {
        return;
      }

      decimalNumberMatches.forEach(function (match) {
        if (match.sub[1].length <= precision) {
          return;
        }
        (0, _utils.report)({
          result: result,
          ruleName: ruleName,
          node: node,
          message: messages.expected(parseFloat(match.sub[0]), precision)
        });
      });
    }
  };
};