"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "rule-trailing-semicolon";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: "Expected a trailing semicolon",
  rejected: "Unexpected trailing semicolon"
});

exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {
    (0, _utils.validateOptions)({ ruleName: ruleName, result: result,
      actual: expectation,
      possible: ["always", "never"]
    });

    root.eachRule(function (rule) {
      // Return early if an empty rule
      if ((0, _utils.cssStatementHasEmptyBlock)(rule)) {
        return;
      }

      if (!rule.last || rule.last.type !== "decl") {
        return;
      }

      // Check semi colon
      if (expectation === "always" && rule.semicolon) {
        return;
      }
      if (expectation === "never" && !rule.semicolon) {
        return;
      }

      var message = expectation === "always" ? messages.expected : messages.rejected;

      (0, _utils.report)({
        message: message,
        node: rule,
        result: result,
        ruleName: ruleName
      });
    });
  };
};