"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _tape = require("tape");

var _tape2 = _interopRequireDefault(_tape);

var _sinon = require("sinon");

var _sinon2 = _interopRequireDefault(_sinon);

var _validateOptions = require("../validateOptions");

var _validateOptions2 = _interopRequireDefault(_validateOptions);

function mockResult() {
  return { warn: _sinon2["default"].spy() };
}

(0, _tape2["default"])("validateOptions for primary options", function (t) {
  var result = mockResult();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "foo",
    possible: ["a", "b", "c"],
    actual: "a"
  });
  t.notOk(result.warn.calledOnce, "passing string equivalence");
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "foo",
    possible: ["a", "b", "c"],
    actual: "d"
  });
  t.ok(result.warn.calledOnce, "failing string equivalence");
  t.ok(result.warn.calledWith("Invalid option value \"d\" for rule \"foo\""));
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "foo",
    possible: [true, false],
    actual: false
  });
  t.notOk(result.warn.calledOnce, "passing boolean equivalence");
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "foo",
    possible: [true, false],
    actual: "a"
  });
  t.ok(result.warn.calledOnce, "failing boolean equivalence");
  t.ok(result.warn.calledWith("Invalid option value \"a\" for rule \"foo\""));
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "bar",
    possible: ["a", function (x) {
      return x > 2;
    }, "c"],
    actual: 3
  });
  t.notOk(result.warn.calledOnce, "passing evaluation");
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "bar",
    possible: ["a", function (x) {
      return x > 2;
    }, "c"],
    actual: 1
  });
  t.ok(result.warn.calledOnce, "failing evaluation");
  t.ok(result.warn.calledWith("Invalid option value \"1\" for rule \"bar\""));
  result.warn.reset();

  t.end();
});

(0, _tape2["default"])("validateOptions for secondary options objects", function (t) {
  var result = mockResult();

  var schema = {
    foo: ["always", "never"],
    bar: [function (x) {
      return typeof x === "number";
    }, "tab"]
  };

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "foo",
    possible: schema,
    actual: { foo: "always", bar: 2 }
  });
  t.notOk(result.warn.called);
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "foo",
    possible: schema,
    actual: { foo: "never", bar: "tab" }
  });
  t.notOk(result.warn.called);
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "bar",
    possible: schema,
    actual: { foo: "neveer", bar: false }
  });
  t.ok(result.warn.calledTwice);
  t.ok(result.warn.calledWith("Invalid value \"neveer\" for option \"foo\" of rule \"bar\""));
  t.ok(result.warn.calledWith("Invalid value \"false\" for option \"bar\" of rule \"bar\""));
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "bar",
    possible: schema,
    actual: { foo: "never", barr: 1 }
  });
  t.ok(result.warn.calledOnce);
  t.ok(result.warn.calledWith("Invalid option name \"barr\" for rule \"bar\""));
  result.warn.reset();

  t.end();
});

(0, _tape2["default"])("validateOptions for secondary options objects with subarrays", function (t) {
  var result = mockResult();

  var schema = {
    bar: ["one", "two", "three", "four"]
  };

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "foo",
    possible: schema,
    actual: { bar: ["one", "three"] }
  });
  t.notOk(result.warn.called);
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "foo",
    possible: schema,
    actual: { bar: ["one", "three", "floor"] }
  });
  t.ok(result.warn.calledOnce);
  t.ok(result.warn.calledWith("Invalid value \"floor\" for option \"bar\" of rule \"foo\""));
  result.warn.reset();

  t.end();
});

(0, _tape2["default"])("validateOptions for `*-no-*` rule with no options", function (t) {
  var result = mockResult();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "no-dancing",
    possible: [],
    actual: undefined
  });
  t.notOk(result.warn.called);
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "no-dancing",
    possible: [],
    actual: "foo"
  });
  t.ok(result.warn.calledOnce);
  t.ok(result.warn.calledWith("Invalid option value \"foo\" for rule \"no-dancing\""));
  result.warn.reset();

  (0, _validateOptions2["default"])({
    result: result,
    ruleName: "no-dancing",
    possible: [],
    actual: false
  });
  t.ok(result.warn.calledOnce);
  t.ok(result.warn.calledWith("Invalid option value \"false\" for rule \"no-dancing\""));
  result.warn.reset();

  t.end();
});